/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.settings.authentication.openid.web.internal.servlet.taglib;

import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.servlet.taglib.BaseJSPDynamicInclude;
import com.liferay.portal.kernel.servlet.taglib.DynamicInclude;

import javax.servlet.ServletContext;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * Adds an OpenID tab to the Authentication section of the Portal Settings user
 * interface in the Control Panel.
 *
 * @author Stian Sigvartsen
 */
@Component(
	immediate = true,
	property = "portal.settings.authentication.tabs.name=openid",
	service = DynamicInclude.class
)
public class PortalSettingsOpenIdAuthenticationJSPDynamicInclude
	extends BaseJSPDynamicInclude {

	@Override
	protected String getJspPath() {
		return "/dynamic_include/com.liferay.portal.settings.web/openid.jsp";
	}

	@Override
	protected Log getLog() {
		return _log;
	}

	@Override
	@Reference(
		target = "(osgi.web.symbolicname=com.liferay.portal.settings.authentication.openid.web)",
		unbind = "-"
	)
	protected void setServletContext(ServletContext servletContext) {
		super.setServletContext(servletContext);
	}

	private static final Log _log = LogFactoryUtil.getLog(
		PortalSettingsOpenIdAuthenticationJSPDynamicInclude.class);

}